pastaWRAP
=========

**pastaWRAP** is a Python wrapper for **R-based Awesome Toolkit for PASTA**,
more commonly known as [**ratPASTA**](https://github.com/ikodvanj/ratPASTA) - an
R package used for processing and visualising data from startle experiments in
rodents or experiments measuring grip strength in rodents. Currently, pastaWRAP only
supports ratPASTA functionality for startle experiments, with plans for adding
griPASTA (grip strength test) functionality wrapping at a later date. The input data
for this package is created with a **PASTA** solution (**Platform for Acoustic STArtle**),
described in detail here:

*Virag, D., Homolak, J., Kodvanj, I., Babic Perhoc, A., Knezovic, A.,
Osmanovic Barilar, J., & Salkovic-Petrisic, M. (2020). Repurposing a
digital kitchen scale for neuroscience research: a complete hardware and
software cookbook for PASTA. BioRxiv, 2020.04.10.035766. 
https://doi.org/10.1101/2020.04.10.035766*

Using the same platform for measuring grip strength in rodents is
described here:

*Homolak, J., Virag, D., Kodvanj, I., Matak, I., Babic Perhoc, A.,
Knezovic, A., Osmanovic Barilar, J., Salkovic-Petrisic, M. (2020).
griPASTA: A hacked kitchen scale for quantification of grip strength in
rodents. BioRxiv, 2020.07.23.217737.
https://doi.org/10.1101/2020.07.23.217737*
